CellOffset

Struct CellOffset 

pub struct CellOffset(pub u32);
Offset to a cell within hive bins data.

All cell offsets in the REGF format are relative to the start of the hive bins data area (which begins at file offset 4096). This newtype prevents accidentally mixing cell offsets with file offsets.

Tuple Fields

0: u32

Implementations

Source

impl CellOffset

pub const NULL: Self

Null/empty sentinel value (0xFFFFFFFF).

pub fn file_offset(self) -> u64

Convert a cell offset to an absolute file offset.

file_offset = 4096 + cell_offset

pub fn is_null(self) -> bool

Check if this is a null/empty reference.