pub struct CellOffset(pub u32);Expand description
Offset to a cell within hive bins data.
All cell offsets in the REGF format are relative to the start of the hive bins data area (which begins at file offset 4096). This newtype prevents accidentally mixing cell offsets with file offsets.
Tuple Fields
0: u32Implementations